#region License
// Copyright (c) 2007 James Newton-King
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
#endregion

using System;
using System.Collections.Generic;
using System.Text;
using NUnit.Framework;
using Utilities.Miscellaneous;
using Utilities.Converters;
using Utilities.Testing;

namespace Utilities.Test.Converters
{
  public class DotNetTypeConverterFixture : TestFixtureBase
  {
    [Test]
    public void ConvertFromString()
    {
      DotNetTypeConverter c = new DotNetTypeConverter();
      Assert.IsTrue(c.CanConvertFrom(typeof(string)));

      Type t;

      t = (Type)c.ConvertFrom("System.String");
      Assert.AreEqual(typeof(string), t);

      t = (Type)c.ConvertFrom("Utilities.Test.Converters.DotNetTypeConverterFixture, Utilities.Test");
      Assert.AreEqual(typeof(DotNetTypeConverterFixture), t);
    }

    [Test]
    [ExpectedException(typeof(TypeLoadException))]
    public void ConvertFromInvalidString()
    {
      DotNetTypeConverter c = new DotNetTypeConverter();
      c.ConvertFrom("pie");
    }

    [Test]
    [ExpectedException(typeof(NotSupportedException), ExpectedMessage = "DotNetTypeConverter cannot convert from (null).")]
    public void ConvertFromNull()
    {
      DotNetTypeConverter c = new DotNetTypeConverter();
      c.ConvertFrom(null);
    }

    [Test]
    public void ConvertToString()
    {
      DotNetTypeConverter c = new DotNetTypeConverter();
      Assert.IsTrue(c.CanConvertTo(typeof(string)));

      string s;

      s = (string)c.ConvertTo(typeof(string), typeof(string));
      Assert.AreEqual("System.String, mscorlib", s);

      s = (string)c.ConvertTo(typeof(DotNetTypeConverterFixture), typeof(string));
      Assert.AreEqual("Utilities.Test.Converters.DotNetTypeConverterFixture, Utilities.Test", s);

      s = (string)c.ConvertTo(null, typeof(string));
      Assert.AreEqual(string.Empty, s);
    }
  }
}