#region License
// Copyright (c) 2007 James Newton-King
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
#endregion

using System;
using System.Collections.Generic;
using System.Text;
using NUnit.Framework;
using Utilities.Miscellaneous;
using Utilities.Converters;
using System.Net.Mail;
using Utilities.Testing;

namespace Utilities.Test.Converters
{
  public class MailAddressTypeConverterFixture : TestFixtureBase
  {
    [Test]
    public void ConvertFromString()
    {
      MailAddressTypeConverter c = new MailAddressTypeConverter();
      Assert.IsTrue(c.CanConvertFrom(typeof(string)));

      MailAddress a;

      a = (MailAddress)c.ConvertFrom("james@test.com");
      Assert.AreEqual("james@test.com", a.Address);

      a = (MailAddress)c.ConvertFrom(@"""James"" <james@test.com>");
      Assert.AreEqual("james@test.com", a.Address);
      Assert.AreEqual("James", a.DisplayName);
    }

    [Test]
    [ExpectedException(typeof(FormatException), ExpectedMessage = "The specified string is not in the form required for an e-mail address.")]
    public void ConvertFromInvalidString()
    {
      MailAddressTypeConverter c = new MailAddressTypeConverter();
      c.ConvertFrom("pie");
    }

    [Test]
    [ExpectedException(typeof(NotSupportedException), ExpectedMessage = "MailAddressTypeConverter cannot convert from (null).")]
    public void ConvertFromNull()
    {
      MailAddressTypeConverter c = new MailAddressTypeConverter();
      c.ConvertFrom(null);
    }

    [Test]
    public void ConvertToString()
    {
      MailAddressTypeConverter c = new MailAddressTypeConverter();
      Assert.IsTrue(c.CanConvertTo(typeof(string)));

      string s;

      s = (string)c.ConvertTo(new MailAddress("james@test.com", "James"), typeof(string));
      Assert.AreEqual(@"""James"" <james@test.com>", s);

      s = (string)c.ConvertTo(null, typeof(string));
      Assert.AreEqual(string.Empty, s);
    }
  }
}